@@ -12,7 +12,7 @@ BEGIN {
 
 BEGIN {
 	$Types::Standard::AUTHORITY = 'cpan:TOBYINK';
-	$Types::Standard::VERSION   = '1.004001';
+	$Types::Standard::VERSION   = '1.004003';
 }
 
 use Type::Library -base;
@@ -1130,6 +1130,19 @@ You can optionally provide a type constraint for the array of subexpressions:
          ],
       ];
 
+Here's an example using L<Regexp::Common>:
+
+   package Local::Host {
+      use Moose;
+      use Regexp::Common;
+      has ip_address => (
+         is         => 'ro',
+         required   => 1.
+         isa        => StrMatch[/^$RE{net}{IPv4}$/],
+         default    => '127.0.0.1',
+      );
+   }
+
 On certain versions of Perl, type constraints of the forms
 C<< StrMatch[qr/../ >> and C<< StrMatch[qr/\A..\z/ >> with any number
 of intervening dots can be optimized to simple length checks.
@@ -1322,7 +1335,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013-2014, 2017-2018 by Toby Inkster.
+This software is copyright (c) 2013-2014, 2017-2019 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
